
Class Quaternion Array
======================

.. autoclass:: ahrs.common.quaternion.QuaternionArray

**Attributes**

.. toctree::
   :titlesonly:
   :maxdepth: 2

   quaternionarray.w
   quaternionarray.x
   quaternionarray.y
   quaternionarray.z
   quaternionarray.v
   quaternionarray.conjugate
   quaternionarray.conj
   quaternionarray.is_pure
   quaternionarray.is_real
   quaternionarray.is_versor
   quaternionarray.is_identity
   quaternionarray.average
   quaternionarray.remove_jumps
   quaternionarray.rotate_by
   quaternionarray.angular_velocities
   quaternionarray.slerp_nan
